##  Deactivating AI Capabilities
You can deactivate AI capabilities in a particular workspace by doing the following:
  1. Go to the Optional Features and Early Access section of the admin settings.
  2. Choose Deactivate next to the AI capability you want to deactivate.
